import type { NextPage } from "next";
import Link from "next/link";
import { ExpressionSetInfo } from "../../components/ExpressionSetInfo/ExpressionSetInfo";
import { Page } from "../../components/Page";
import { useExpressionsInSet } from "../../hooks/useExpressionsInSet";
import { useQueriedExpressionSet } from "../../hooks/useQueriedExpressionSet";
import { PageWithError } from "../../views/PageWithError/PageWithError";

const ExpressionSetDetailsPage: NextPage = () => {
  const expression_set = useQueriedExpressionSet();
  const expressions = useExpressionsInSet(expression_set?.id);

  // Fallback for expression set not found
  if (!expression_set) {
    return <PageWithError message="Expression set not found" />;
  }

  // Fallback for expression set empty
  if (expressions.length === 0)
    return (
      <Page>
        <div className="page-with-padding scroll">
          <ExpressionSetInfo
            id={expression_set.id}
            name={expression_set.name}
            description={expression_set.description}
            expression_count={expressions.length}
          />
          <p className="text-details">No expressions left in this set.</p>
        </div>
      </Page>
    );

  return (
    <Page>
      <div className="page-with-bottom-navigation">
        <section className="padding-small scroll">
          <ExpressionSetInfo
            id={expression_set.id}
            name={expression_set.name}
            description={expression_set.description}
            expression_count={expressions.length}
          />
        </section>
        <section className="navigation-bottom">
          <Link
            href={{
              pathname: "/expression-sets/practice",
              query: { "set-id": expression_set.id },
            }}
            passHref
          >
            <a className="navigation-item bottom text-navigation grow">
              <span>Practice this set</span>
            </a>
          </Link>
        </section>
      </div>
    </Page>
  );
};

export default ExpressionSetDetailsPage;
