import type { NextPage } from "next";
import Link from "next/link";
import { ExpressionSetCard } from "../../components/ExpressionSetCard";
import { Page } from "../../components/Page";
import { useExpressionData } from "../../hooks/useExpressionData";
import { useExpressionsInSet } from "../../hooks/useExpressionsInSet";
import { ExpressionSet } from "../../model";

const ExpressionSetListPage: NextPage = () => {
  const { expression_sets } = useExpressionData();

  return (
    <Page>
      <div className="page-with-padding content-list scroll">
        {expression_sets.map(({ id, name, description }) => (
          <ExpressionSetLink
            key={id}
            id={id}
            name={name}
            description={description}
          />
        ))}
      </div>
    </Page>
  );
};

function ExpressionSetLink({ id, description, name }: ExpressionSet) {
  const expressions = useExpressionsInSet(id);
  return (
    <Link
      href={{
        pathname: "/expression-sets/details",
        query: { "set-id": id },
      }}
      passHref
    >
      <a>
        <ExpressionSetCard
          name={name}
          description={description}
          expression_count={expressions.length}
        />
      </a>
    </Link>
  );
}

export default ExpressionSetListPage;
