import type { NextPage } from "next";
import Link from "next/link";
import { useRouter } from "next/router";
import { useState } from "react";
import { ExpressionCard } from "../../components";
import { Page } from "../../components/Page";
import { useExpressionCategories } from "../../hooks/useExpressionCategories";
import { useQueriedExpressionSet } from "../../hooks/useQueriedExpressionSet";
import { useRandomExpressionInSet } from "../../hooks/useRandomExpressionInSet";
import { Category, Expression } from "../../model";
import { PageWithError } from "../../views/PageWithError/PageWithError";

// Do random selection here so we don't keep flipping states with interaction
const ExpressionPracticePage: NextPage = () => {
  const expression_set = useQueriedExpressionSet();
  const expression = useRandomExpressionInSet(expression_set?.id);
  const categories = useExpressionCategories(expression?.id);

  // Fallback views for expression set content not found
  if (!expression_set) {
    return <PageWithError message="Expression set not found" />;
  }
  if (!expression) {
    return <PageWithError message="No expressions left in this set" />;
  }
  return (
    <ExpressionCardPracticeView
      key={expression.id}
      expression={expression}
      categories={categories}
    />
  );
};

interface ExpressionCardPracticeViewProps {
  expression: Expression;
  categories: Category[];
}

// Handle internal state here
function ExpressionCardPracticeView({
  expression,
  categories,
}: ExpressionCardPracticeViewProps) {
  const { query, pathname } = useRouter();
  const [revealed, setRevealed] = useState(false);
  return (
    <Page>
      <div className="page-with-bottom-navigation">
        <section className="padding-small scroll">
          <ExpressionCard
            prompt={expression.prompt}
            categories={categories.map((category) => category.name)}
            description={expression.description}
            show_description={revealed}
          />
        </section>
        <section className="navigation-bottom">
          {revealed ? (
            <>
              <Link href={{ pathname, query }} passHref>
                <a className="navigation-item bottom text-navigation grow">
                  <div>Wrong</div>
                </a>
              </Link>
              <Link href={{ pathname, query }} passHref>
                <a className="navigation-item bottom text-navigation grow">
                  <div>Right</div>
                </a>
              </Link>
            </>
          ) : (
            <button
              className="navigation-item bottom text-navigation grow"
              onClick={() => setRevealed(true)}
            >
              Reveal
            </button>
          )}
        </section>
      </div>
    </Page>
  );
}

export default ExpressionPracticePage;
